==> scitools-iris-3.0.1.tar.gz: scitools-iris-3.0.1/README.md <==
<h1 align="center">
  <a href="https://scitools.org.uk/iris/docs/latest/">
   <img src="docs/iris/src/_static/iris-logo-title.png" alt="Iris" width="300"></a><br>
</h1>


<h4 align="center">
    Iris is a powerful, format-agnostic, community-driven Python package for
    analysing and visualising Earth science data
</h4>

<p align="center">
<a href="https://cirrus-ci.com/github/SciTools/iris">
<img src="https://api.cirrus-ci.com/github/SciTools/iris.svg?branch=master"
     alt="Cirrus-CI" /></a>
<a href='https://scitools-iris.readthedocs.io/en/latest/?badge=latest'>
<img src='https://readthedocs.org/projects/scitools-iris/badge/?version=latest'
     alt='Documentation Status' /></a>
<a href="https://anaconda.org/conda-forge/iris">
<img src="https://img.shields.io/conda/dn/conda-forge/iris.svg"
     alt="conda-forge downloads" /></a>
<a href="https://github.com/SciTools/iris/graphs/contributors">
<img src="https://img.shields.io/github/contributors/SciTools/iris.svg"
     alt="# contributors" /></a>
<a href="https://github.com/SciTools/iris/releases">
<img src="https://img.shields.io/github/tag/SciTools/iris.svg"
     alt="Latest version" /></a>
<a href="https://github.com/SciTools/iris/commits/master">
<img src="https://img.shields.io/github/commits-since/SciTools/iris/latest.svg"
     alt="Commits since last release" /></a>
<a href="https://zenodo.org/badge/latestdoi/5312648">
<img src="https://zenodo.org/badge/5312648.svg"
     alt="zenodo" /></a>
<a href="https://github.com/psf/black">
<img src="https://img.shields.io/badge/code%20style-black-000000.svg"
     alt="black" /></a>
<a href="https://twitter.com/scitools_iris">
<img src="https://img.shields.io/twitter/follow/scitools_iris?style=social"
     alt="twitter" /></a>
</p>

<p align="center">
See the <a href="https://scitools-iris.readthedocs.io/en/latest/">documentation</a> for the <b>latest development version</b> of Iris.
</P>

==> scitools-iris-3.0.3.tar.gz: scitools-iris-3.0.3/README.md <==
<h1 align="center">
  <a href="https://scitools-iris.readthedocs.io/en/latest/">
   <img src="https://scitools-iris.readthedocs.io/en/latest/_static/iris-logo-title.png" alt="Iris" width="300"></a><br>
</h1>


<h4 align="center">
    Iris is a powerful, format-agnostic, community-driven Python package for
    analysing and visualising Earth science data
</h4>

<p align="center">
<a href="https://cirrus-ci.com/github/SciTools/iris">
<img src="https://api.cirrus-ci.com/github/SciTools/iris.svg?branch=master"
     alt="Cirrus-CI" /></a>
<a href='https://scitools-iris.readthedocs.io/en/latest/?badge=latest'>
<img src='https://readthedocs.org/projects/scitools-iris/badge/?version=latest'
     alt='Documentation Status' /></a>
<a href="https://anaconda.org/conda-forge/iris">
<img src="https://img.shields.io/conda/dn/conda-forge/iris.svg"
     alt="conda-forge downloads" /></a>
<a href="https://github.com/SciTools/iris/graphs/contributors">
<img src="https://img.shields.io/github/contributors/SciTools/iris.svg"
     alt="# contributors" /></a>
<a href="https://github.com/SciTools/iris/releases">
<img src="https://img.shields.io/github/tag/SciTools/iris.svg"
     alt="Latest version" /></a>
<a href="https://github.com/SciTools/iris/commits/master">
<img src="https://img.shields.io/github/commits-since/SciTools/iris/latest.svg"
     alt="Commits since last release" /></a>
<a href="https://zenodo.org/badge/latestdoi/5312648">
<img src="https://zenodo.org/badge/5312648.svg"
     alt="zenodo" /></a>
<a href="https://github.com/psf/black">
<img src="https://img.shields.io/badge/code%20style-black-000000.svg"
     alt="black" /></a>
<a href="https://twitter.com/scitools_iris">
<img src="https://img.shields.io/twitter/follow/scitools_iris?style=social"
     alt="twitter" /></a>
</p>

<p align="center">
See the <a href="https://scitools-iris.readthedocs.io/en/latest/">documentation</a> for the <b>latest development version</b> of Iris.
</P>
